@@ -27,7 +27,7 @@
 #ifndef GNOME_DISABLE_DEPRECATED_SOURCE
 
 /* Must be before all other gnome includes!! */
-#include "gnome-i18nP.h"
+#include <glib/gi18n-lib.h>
 
 #include <libgnome/gnome-util.h>
 
@@ -38,7 +38,6 @@
 #include "gnome-uidefs.h"
 #include "gnome-appbar.h"
 
-#include <gdk/gdkx.h>
 #include <gtk/gtk.h>
 
 static gboolean
@@ -106,7 +105,7 @@ static void gnome_app_message_bar (GnomeApp * app, const gchar * message)
 
 
 /**
- * gnome_app_message:
+ * gnome_app_message
  * @app: Pointer to GNOME app object
  * @message: Text of message to be displayed
  *
@@ -146,7 +145,7 @@ gnome_app_error_bar(GnomeApp * app, const gchar * error)
 
 
 /**
- * gnome_app_error:
+ * gnome_app_error
  * @app: Pointer to GNOME app object
  * @error: Text of error message to be displayed
  *
@@ -183,7 +182,7 @@ static void gnome_app_warning_bar (GnomeApp * app, const gchar * warning)
 
 
 /**
- * gnome_app_warning:
+ * gnome_app_warning
  * @app: Pointer to GNOME app object
  * @warning: Text of warning message to be displayed
  *
@@ -250,7 +249,7 @@ static const guint32 flash_length = 3000; /* 3 seconds, I hope */
 
 
 /**
- * gnome_app_flash:
+ * gnome_app_flash
  * @app: Pointer to GNOME app object
  * @flash: Text of message to be flashed
  *
@@ -371,11 +370,11 @@ gnome_app_reply_bar(GnomeApp * app, const gchar * question,
 
 
 /**
- * gnome_app_question:
+ * gnome_app_question
  * @app: Pointer to GNOME app object
  * @question: Text of question to be displayed
- * @callback: The callback to use
- * @data: Pointer to data
+ * @callback:
+ * @data:
  *
  * Description:
  * Ask a yes or no question, and call the callback when it's answered.
@@ -406,7 +405,7 @@ gnome_app_question (GnomeApp * app, const gchar * question,
 
 
 /**
- * gnome_app_question_modal:
+ * gnome_app_question_modal
  * @app: Pointer to GNOME app object
  * @question: Text of question to be displayed
  * @callback:
@@ -441,7 +440,7 @@ gnome_app_question_modal (GnomeApp * app, const gchar * question,
 
 
 /**
- * gnome_app_ok_cancel:
+ * gnome_app_ok_cancel
  * @app: Pointer to GNOME app object
  * @message: Text of message to be displayed
  * @callback:
@@ -475,7 +474,7 @@ gnome_app_ok_cancel (GnomeApp * app, const gchar * message,
 
 
 /**
- * gnome_app_ok_cancel_modal:
+ * gnome_app_ok_cancel_modal
  * @app: Pointer to GNOME app object
  * @message: Text of message to be displayed
  * @callback:
@@ -572,7 +571,7 @@ gnome_app_request_bar  (GnomeApp * app, const gchar * prompt,
 
 
 /**
- * gnome_app_request_string:
+ * gnome_app_request_string
  * @app: Pointer to GNOME app object
  * @prompt: Text of prompt to be displayed
  * @callback:
@@ -607,7 +606,7 @@ gnome_app_request_string (GnomeApp * app, const gchar * prompt,
 
 
 /**
- * gnome_app_request_password:
+ * gnome_app_request_password
  * @app: Pointer to GNOME app object
  * @prompt: Text of prompt to be displayed
  * @callback:
@@ -723,7 +722,7 @@ stop_progress_cb(GnomeApp * app, GnomeAppProgressKey key)
 /* FIXME share code between manual and timeout */
 
 /**
- * gnome_app_progress_timeout:
+ * gnome_app_progress_timeout
  * @app:
  * @description:
  * @interval:
@@ -781,7 +780,7 @@ gnome_app_progress_timeout (GnomeApp * app,
 
 
 /**
- * gnome_app_progress_manual:
+ * gnome_app_progress_manual
  * @app:
  * @description:
  * @cancel_cb:
@@ -829,7 +828,7 @@ gnome_app_progress_manual (GnomeApp * app,
 }
 
 /**
- * gnome_app_set_progress:
+ * gnome_app_set_progress
  * @key:
  * @percent:
  *
@@ -859,7 +858,7 @@ static void progress_timeout_remove(ProgressKeyReal * key)
 }
 
 /**
- * gnome_app_progress_done:
+ * gnome_app_progress_done
  * @key:
  *
  * Description:
