@@ -39,20 +39,10 @@
 
 #include <unistd.h> /*getcwd*/
 #include <gdk-pixbuf/gdk-pixbuf.h>
-#include <gtk/gtkbutton.h>
-#include <gtk/gtkdnd.h>
-#include <gtk/gtkentry.h>
-#include <gtk/gtkfilesel.h>
-#include <gtk/gtkfilechooser.h>
-#include <gtk/gtkframe.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkmain.h>
-#include <gtk/gtksignal.h>
-#include <gtk/gtkpixmap.h>
-#include <gtk/gtkscrolledwindow.h>
+#include <gtk/gtk.h>
 
 /* Must be before all other gnome includes!! */
-#include "gnome-i18nP.h"
+#include <glib/gi18n-lib.h>
 
 #include <libgnome/gnome-util.h>
 #include <libgnome/gnome-config.h>
@@ -65,7 +55,6 @@
 #include "gnome-icon-entry.h"
 #include "libgnomeui-access.h"
 #include <sys/stat.h>
-#include <unistd.h>
 #include <string.h>
 
 #include <glib/gstdio.h>
@@ -115,8 +104,6 @@ static void ientry_browse               (GnomeIconEntry *ientry);
 static gboolean ientry_mnemonic_activate (GtkWidget *widget, gboolean group_cycling);
 static void icon_selected_cb (GnomeIconEntry * ientry);
 
-static GtkTargetEntry drop_types[] = { { "text/uri-list", 0, 0 } };
-
 /* Property IDs */
 enum {
 	PROP_0,
@@ -319,7 +306,7 @@ update_icon (GnomeIconEntry *ientry)
 		if(GTK_IS_IMAGE(child)) {
 			gtk_drag_source_unset (ientry->_priv->pickbutton);
 			gtk_widget_destroy(child);
-			child = gtk_label_new(_("No Icon"));
+			child = gtk_label_new(_("Choose Icon"));
 			gtk_widget_show(child);
 			gtk_container_add(GTK_CONTAINER(ientry->_priv->pickbutton),
 					  child);
@@ -358,15 +345,16 @@ update_icon (GnomeIconEntry *ientry)
 					  G_CALLBACK (drag_data_get), ientry);
 			gtk_drag_source_set (child,
 					     GDK_BUTTON1_MASK|GDK_BUTTON3_MASK,
-					     drop_types, 1,
+					     NULL, 0,
 					     GDK_ACTION_COPY);
+			gtk_drag_source_add_uri_targets (child);
 		}
 	}
 	g_object_unref (scaled);
 #if 0
 	gtk_drag_source_set (ientry->_priv->pickbutton,
 			     GDK_BUTTON1_MASK|GDK_BUTTON3_MASK,
-			     drop_types, 1,
+			     drop_types, G_N_ELEMENTS (drop_types),
 			     GDK_ACTION_COPY);
 #endif
 }
@@ -375,6 +363,7 @@ static void
 entry_activated(GtkWidget *widget, GnomeIconEntry *ientry)
 {
 	GnomeIconEntryPrivate *priv;
+	GnomeIconSelection    *sel;
 	struct stat buf;
 	const gchar *filename;
 
@@ -383,18 +372,21 @@ entry_activated(GtkWidget *widget, GnomeIconEntry *ientry)
 	g_return_if_fail (ientry != NULL);
 	g_return_if_fail (GNOME_IS_ICON_ENTRY (ientry));
 
-	priv = ientry->_priv;
-
 	filename = gtk_entry_get_text (GTK_ENTRY (widget));
 
 	if (!filename)
 		return;
 
+	priv = ientry->_priv;
+
 	g_stat (filename, &buf);
 	if (S_ISDIR (buf.st_mode)) {
-		gnome_icon_selection_clear (GNOME_ICON_SELECTION (priv->icon_sel), TRUE);
-		gnome_icon_selection_add_directory (GNOME_ICON_SELECTION (priv->icon_sel), filename);
-		gnome_icon_selection_show_icons (GNOME_ICON_SELECTION (priv->icon_sel));
+		sel  = GNOME_ICON_SELECTION (priv->icon_sel);
+		if (sel) {
+			gnome_icon_selection_clear (sel, TRUE);
+			gnome_icon_selection_add_directory (sel, filename);
+			gnome_icon_selection_show_icons (sel);
+		}
 	} else {
 		/* We pretend like ok has been called */
 		g_free (priv->picked_file);
@@ -405,6 +397,7 @@ entry_activated(GtkWidget *widget, GnomeIconEntry *ientry)
 	}
 }
 
+#if 0
 static void
 setup_preview(GtkWidget *widget)
 {
@@ -461,6 +454,7 @@ setup_preview(GtkWidget *widget)
 	gtk_widget_show(pp);
 	gtk_container_add(GTK_CONTAINER(frame),pp);
 }
+#endif
 
 static void
 ientry_destroy (GtkObject *object)
@@ -523,10 +517,12 @@ entry_changed(GtkEntry *entry)
 static void
 browse_clicked(GnomeFileEntry *fentry, GnomeIconEntry *ientry)
 {
-	GtkWidget *w;
 	GtkFileChooser *fc;
+#if 0
+	GtkWidget *w;
 	GClosure *closure;
 	gchar *path;
+#endif
 
 	g_return_if_fail (fentry != NULL);
 	g_return_if_fail (GNOME_IS_FILE_ENTRY (fentry));
@@ -994,7 +990,7 @@ gnome_icon_entry_instance_init (GnomeIconEntry *ientry)
 	w = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
 	gtk_widget_show(w);
 	gtk_box_pack_start (GTK_BOX (ientry), w, TRUE, TRUE, 0);
-	ientry->_priv->pickbutton = gtk_button_new_with_label(_("No Icon"));
+	ientry->_priv->pickbutton = gtk_button_new_with_label(_("Choose Icon"));
 	/* Set our accessible name and description */
 	_add_atk_name_desc (GTK_WIDGET (ientry->_priv->pickbutton),
 			    _("Icon Selector"),
@@ -1004,7 +1000,9 @@ gnome_icon_entry_instance_init (GnomeIconEntry *ientry)
 			   GTK_DEST_DEFAULT_MOTION |
 			   GTK_DEST_DEFAULT_HIGHLIGHT |
 			   GTK_DEST_DEFAULT_DROP,
-			   drop_types, 1, GDK_ACTION_COPY);
+			   NULL, 0,
+			   GDK_ACTION_COPY);
+	gtk_drag_dest_add_uri_targets (GTK_WIDGET (ientry->_priv->pickbutton));
 	g_signal_connect (ientry->_priv->pickbutton, "drag_data_received",
 			  G_CALLBACK (drag_data_received),
 			  ientry);
