@@ -36,20 +36,9 @@
 #include <sys/stat.h>
 #include <unistd.h>
 #include <string.h>
-#include <gtk/gtkbutton.h>
-#include <gtk/gtkdnd.h>
-#include <gtk/gtkentry.h>
-#include <gtk/gtkfilesel.h>
-#include <gtk/gtkfilechooser.h>
-#include <gtk/gtkframe.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkmain.h>
-#include <gtk/gtksignal.h>
-#include <gtk/gtkpixmap.h>
-#include <gtk/gtkscrolledwindow.h>
-#include <gtk/gtktreeview.h>
+#include <gtk/gtk.h>
 
-#include "gnome-i18nP.h"
+#include <glib/gi18n-lib.h>
 
 #include <libgnome/gnome-util.h>
 #include "gnome-file-entry.h"
@@ -86,8 +75,6 @@ static void pentry_set_property (GObject *object, guint param_id,
 static void pentry_get_property (GObject *object, guint param_id,
 				 GValue *value, GParamSpec *pspec);
 
-static GtkTargetEntry drop_types[] = { { "text/uri-list", 0, 0 } };
-
 /* Property IDs */
 enum {
 	PROP_0,
@@ -181,7 +168,7 @@ refresh_preview(GnomePixmapEntry *pentry)
 		g_free(t);
 		return;
 	}
-	if(!t || !g_file_test(t,G_FILE_TEST_IS_SYMLINK|G_FILE_TEST_IS_REGULAR) ||
+	if(!t || !g_file_test(t,(G_FILE_TEST_IS_SYMLINK & !G_FILE_TEST_IS_DIR)|G_FILE_TEST_IS_REGULAR) ||
 	   !(pixbuf = gdk_pixbuf_new_from_file (t, NULL))) {
 		if (GTK_IS_IMAGE (pentry->_priv->preview)) {
 			gtk_drag_source_unset (pentry->_priv->preview_sw);
@@ -214,15 +201,17 @@ refresh_preview(GnomePixmapEntry *pentry)
 					  G_CALLBACK (drag_data_get), pentry);
 			gtk_drag_source_set (pentry->_priv->preview,
 					     GDK_BUTTON1_MASK|GDK_BUTTON3_MASK,
-					     drop_types, 1,
+					     NULL, 0,
 					     GDK_ACTION_COPY);
+			gtk_drag_source_add_uri_targets (pentry->_priv->preview);
 		}
 		g_signal_connect (G_OBJECT (pentry->_priv->preview->parent), "drag_data_get",
 				  G_CALLBACK (drag_data_get), pentry);
 		gtk_drag_source_set (pentry->_priv->preview->parent,
 				     GDK_BUTTON1_MASK|GDK_BUTTON3_MASK,
-				     drop_types, 1,
+				     NULL, 0,
 				     GDK_ACTION_COPY);
+		gtk_drag_source_add_uri_targets (pentry->_priv->preview->parent);
 	}
 	g_free(pentry->_priv->last_preview);
 	pentry->_priv->last_preview = t;
@@ -240,9 +229,11 @@ changed_timeout_func(gpointer data)
 	tmp = changed_pentries;
 	changed_pentries = NULL;
 	if(tmp) {
+		GDK_THREADS_ENTER();
 		for(li=tmp;li!=NULL;li=g_slist_next(li)) {
 			refresh_preview(li->data);
 		}
+		GDK_THREADS_LEAVE();
 		g_slist_free(tmp);
 		return TRUE;
 	}
@@ -300,7 +291,7 @@ setup_preview(GtkTreeSelection *selection, GtkWidget *widget)
 	if(pp)
 		gtk_widget_destroy(pp);
 
-	if(!p || !g_file_test(p,G_FILE_TEST_IS_SYMLINK|G_FILE_TEST_IS_REGULAR) ||
+	if(!p || !g_file_test(p,(G_FILE_TEST_IS_SYMLINK & !G_FILE_TEST_IS_DIR) |G_FILE_TEST_IS_REGULAR) ||
 	   !(pixbuf = gdk_pixbuf_new_from_file (p, NULL)))
 		return;
 
@@ -457,7 +448,7 @@ drag_data_get  (GtkWidget          *widget,
 	g_free(file);
 	gtk_selection_data_set (selection_data,
 				selection_data->target,
-				8, string, strlen(string)+1);
+				8, (unsigned char *)string, strlen(string)+1);
 	g_free(string);
 }
 
@@ -538,9 +529,6 @@ void
 gnome_pixmap_entry_construct (GnomePixmapEntry *pentry, const gchar *history_id,
 			      const gchar *browse_dialog_title, gboolean do_preview)
 {
-	GtkWidget *gentry;
-	gentry = gnome_file_entry_gnome_entry(GNOME_FILE_ENTRY(pentry));
-
 	gnome_file_entry_construct (GNOME_FILE_ENTRY (pentry),
 				    history_id,
 				    browse_dialog_title);
